body {{ 
    color: #000;
    background-color: #fff;
}}
::-webkit-scrollbar {{
    height: 12px;
    width: 12px;
    background: silver;
}}
::-webkit-scrollbar-thumb {{
    background: gray;
    -webkit-border-radius: 1ex;
    -webkit-box-shadow: 0px 1px 2px rgba(0, 0, 0, 0.75);
}}
::-webkit-scrollbar-thumb:hover {{
    background: #000;
}}
::-webkit-scrollbar-corner {{
    background: {QTMATERIAL_SECONDARYLIGHTCOLOR};
}}
p {{ 
    color: #000;
}}
a {{
    color: #000;
}}
.msg-user {{
    color: #3a3a3a !important;
}}
.msg-user p {{
    color: #3a3a3a !important;
}}
.msg-bot {{
    color: #000;
    border-bottom: 1px solid #ebebeb;
}}
.msg-highlight {{
    border: 1px solid #dfdfdf;
    background-color: #eaeaea;
}}
.cmd {{
    color: #4d4d4d;
    text-decoration: none;
}}
.ts {{
    color: #4d4d4d;
}}
.list {{
}}
code {{
    color: #000;
}}
.code-wrapper {{
    border: 1px solid #e1e1e1;
    color: #fff;
}}
.code-header-wrapper {{
    color: #fff;
    background: #e1e1e1;
}}
.code-header-copy {{
    color: #444444;
}}
.code-header-copy:hover {{
    color: #000;
}}
.code-header-lang {{
    color: #777777;
}}